ArquivoRecibo class
Arquivo do recibo
Constructors
- ArquivoRecibo({required String nomeArquivo, required String pdf})
-
ArquivoRecibo.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- nomeArquivo → String
-
Nome do arquivo do recibo para ser utilizado no processo de decodificação do base64
Ex. "recibo-pgdasd-{numeroDeclaracao}.pdf"
final
- pdf → String
-
Obtém o arquivo em base 64 para conversão em PDF
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited