ConsultarPagamentosResponse class
Response para consulta de pagamentos
- Inheritance
-
- Object
- PagtoWebResponse
- ConsultarPagamentosResponse
Constructors
-
ConsultarPagamentosResponse({required int status, required List<
MensagemNegocio> mensagens, required List<DocumentoArrecadacao> dados}) -
ConsultarPagamentosResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
dados
→ List<
DocumentoArrecadacao> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mensagens
→ List<
MensagemNegocio> -
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
finalinherited
- sucesso → bool
-
Verifica se a resposta foi bem-sucedida
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited