ContarPagamentosRequest class
Request para contar pagamentos (CONTACONSDOCARRPG73)
- Inheritance
-
- Object
- BaseRequest
- PagtoWebRequest
- ContarPagamentosRequest
Constructors
Properties
-
codigoReceitaLista
→ List<
String> ? -
final
-
codigoTipoDocumentoLista
→ List<
String> ? -
final
- contribuinteNumero → String
-
Número do documento do contribuinte (CPF ou CNPJ)
finalinherited
- contribuinteTipo → int
-
Tipo do documento (1 = CPF, 2 = CNPJ) - detectado automaticamente
finalinherited
- dataFinal → String?
-
final
- dataInicial → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
numeroDocumentoLista
→ List<
String> ? -
final
- pedidoDados → PedidoDados
-
Dados específicos do pedido (ID do sistema, serviço e dados)
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valorFinal → double?
-
final
- valorInicial → double?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJsonWithAuth(
{required String contratanteNumero, required int contratanteTipo, required String autorPedidoDadosNumero, required int autorPedidoDadosTipo}) → Map< String, dynamic> -
Cria o JSON completo da requisição incluindo dados de autenticação
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited