ParcmeiErrors class
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
analyzeError(
String codigo, String mensagem) → ParcmeiErrorAnalysis -
getAllErrors(
) → List< ParcmeiErrorInfo> -
getAvisos(
) → List< ParcmeiErrorInfo> -
getEntradasIncorretas(
) → List< ParcmeiErrorInfo> -
getErrorInfo(
String codigo) → ParcmeiErrorInfo? -
getErrorsByCategory(
) → Map< String, List< ParcmeiErrorInfo> > -
getErros(
) → List< ParcmeiErrorInfo> -
getSucessos(
) → List< ParcmeiErrorInfo> -
isKnownError(
String codigo) → bool