RegimePisCofins enum

Regime de apuração do PIS/Pasep e/ou da Cofins

Inheritance
Available extensions

Values

naoCumulativa → const RegimePisCofins
const RegimePisCofins(1, 'Não-cumulativa')
cumulativa → const RegimePisCofins
const RegimePisCofins(2, 'Cumulativa')
naoCumulativaECumulativa → const RegimePisCofins
const RegimePisCofins(3, 'Não-cumulativa e Cumulativa')
naoSeAplica → const RegimePisCofins
const RegimePisCofins(4, 'Não se aplica')

Properties

codigo int
final
descricao String
final
hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromCodigo(int codigo) RegimePisCofins?

Constants

values → const List<RegimePisCofins>
A constant List of the values in this enum, in order of their declaration.