RelpsnErrorAnalysis class

Análise detalhada de um erro

Constructors

RelpsnErrorAnalysis({required String codigo, required String mensagem, required RelpsnErrorInfo? errorInfo, required bool isKnown, required RelpsnErrorSeverity severity, required bool canRetry, required bool requiresUserAction})

Properties

canRetry bool
final
codigo String
final
errorInfo RelpsnErrorInfo?
final
hashCode int
The hash code for this object.
no setterinherited
isCritical bool
Retorna se é um erro crítico
no setter
isIgnorable bool
Retorna se é um erro que pode ser ignorado
no setter
isKnown bool
final
isSystemError bool
Retorna se é um erro de sistema
no setter
isValidationError bool
Retorna se é um erro de validação
no setter
isWarning bool
Retorna se é um aviso
no setter
mensagem String
final
recommendedAction String
Retorna a ação recomendada
no setter
requiresUserAction bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
severity RelpsnErrorSeverity
final
summary String
Retorna uma descrição resumida do erro
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited