CacheToken class
Modelo para dados de cache do token
Constructors
- CacheToken({required String token, required DateTime dataExpiracao, required DateTime dataCriacao})
-
CacheToken.fromJson(Map<
String, dynamic> json) -
factory
Properties
- dataCriacao → DateTime
-
final
- dataExpiracao → DateTime
-
final
- expiraEmBreve → bool
-
Indica se o token expira em menos de 1 hora
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- isValido → bool
-
Verifica se o token ainda é válido
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tempoRestante → Duration
-
Tempo restante até expiração
no setter
- token → String
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited