ContarPagamentosResponse class
Response para contagem de pagamentos
- Inheritance
-
- Object
- PagtoWebResponse
- ContarPagamentosResponse
Constructors
-
ContarPagamentosResponse({required int status, required List<
MensagemNegocio> mensagens, required int quantidade}) -
ContarPagamentosResponse.fromJson(Map<
String, dynamic> json) -
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
mensagens
→ List<
MensagemNegocio> -
finalinherited
- quantidade → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- status → int
-
finalinherited
- sucesso → bool
-
Verifica se a resposta foi bem-sucedida
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited