DetalhamentoDasAvulso class
Detalhamento do DAS Avulso
Constructors
-
DetalhamentoDasAvulso({required String periodoApuracao, required String numeroDocumento, required String dataVencimento, required String dataLimiteAcolhimento, required ValoresDasAvulso valores, String? observacao1, String? observacao2, String? observacao3, List<
ComposicaoDasAvulso> ? composicao}) -
DetalhamentoDasAvulso.fromJson(Map<
String, dynamic> json) -
factory
Properties
-
composicao
→ List<
ComposicaoDasAvulso> ? -
Composição do DAS gerado
final
- dataLimiteAcolhimento → String
-
Data limite para acolhimento no formato AAAAMMDD
final
- dataVencimento → String
-
Data de vencimento no formato AAAAMMDD
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- numeroDocumento → String
-
Número do documento gerado
final
- observacao1 → String?
-
Observação 1
final
- observacao2 → String?
-
Observação 2
final
- observacao3 → String?
-
Observação 3
final
- periodoApuracao → String
-
Período de Apuração no formato AAAAMM
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- valores → ValoresDasAvulso
-
Discriminação dos valores
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited