TokenExpiredException class
Lançada quando o token de autenticação expira
- Inheritance
-
- Object
- AuthException
- TokenExpiredException
Constructors
- TokenExpiredException(DateTime expiredAt)
-
Cria exceção indicando expiração em
expiredAt.
Properties
- expiredAt → DateTime
-
Data/hora em que o token expirou.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Mensagem de erro descritiva.
finalinherited
- originalError → dynamic
-
Erro original que originou esta exceção, se houver.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited